/* Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */
package org.dive4elements.river.artifacts.sinfo.flowdepthdev;

import java.util.Collection;

import org.dive4elements.river.artifacts.sinfo.common.AbstractSInfoCalculationResult;
import org.dive4elements.river.artifacts.sinfo.common.SInfoResultRow;
import org.dive4elements.river.artifacts.sinfo.util.BedHeightInfo;
import org.dive4elements.river.artifacts.sinfo.util.WstInfo;

/**
 * Contains the results of a {@link FlowDepthCalculation}.
 *
 * @author Gernot Belger
 */
final class FlowDepthDevelopmentCalculationResult extends AbstractSInfoCalculationResult {

    private static final long serialVersionUID = 1L;

    private final BedHeightInfo currentSounding;

    private final BedHeightInfo historicalSounding;

    private final WstInfo historicalWst;

    private final WstInfo currentWst;

    public FlowDepthDevelopmentCalculationResult(final String label, final WstInfo currentWst, final WstInfo historicalWst, final BedHeightInfo currentSounding,
            final BedHeightInfo historicalSounding, final Collection<SInfoResultRow> rows) {
        // FIXME: bad abstraction if we give null here...
        super(label, null, rows);

        this.currentWst = currentWst;
        this.historicalWst = historicalWst;

        this.currentSounding = currentSounding;
        this.historicalSounding = historicalSounding;
    }

    public WstInfo getCurrentWst() {
        return this.currentWst;
    }

    public WstInfo getHistoricalWst() {
        return this.historicalWst;
    }

    public BedHeightInfo getCurrentSounding() {
        return this.currentSounding;
    }

    public BedHeightInfo getHistoricalSounding() {
        return this.historicalSounding;
    }

    public String getWaterlevelDifferenceLabel() {
        return new StringBuilder(). //
                append(this.currentWst.getLabel()). //
                append(" - "). //
                append(this.historicalWst.getLabel()). //
                toString();
    }

    public String getBedHeightDifferenceLabel() {
        return new StringBuilder(). //
                append(this.currentSounding.getDescription()). //
                append(" - "). //
                append(this.historicalSounding.getDescription()). //
                toString();
    }

    public String getFlowDepthCurrentLabel() {
        return new StringBuilder(). //
                append(this.currentWst.getLabel()). //
                append(" - "). //
                append(this.currentSounding.getDescription()). //
                toString();
    }

    public String getFlowDepthHistoricalLabel() {
        return new StringBuilder(). //
                append(this.historicalWst.getLabel()). //
                append(" - "). //
                append(this.historicalSounding.getDescription()). //
                toString();
    }
}